
#ifndef _GrLcm_H_
#define _GrLcm_H_


/*

DM&P GrLCM
Copyright (C) 2002 by DM&P.

This library is for DM&P product user only.

*/

#define LCM_FONT_5X7    0
#define LCM_FONT_8X10   1
#define LCM_FONT_8X16   4

#define LCM_GPIO    0
#define LCM_PRN     1
#define LCM_VGA     2

#define LCM_122X32   0
#define LCM_128X64   1
#define LCM_320X240  2
#define LCM_128X128  3
#define LCM_240X128  4
#define LCM_240X64   5
#define LCM_320X240A 6

#define LCM_ENGLISH       0
#define LCM_CHINESE_BIG5  1
#define LCM_CHINESE_GB    2
#define LCM_JAPANESE_SJIS 3
#define LCM_GREEK         4
#define LCM_THAI          5

#ifdef __cplusplus
extern "C" {
#endif

char *GrLcm_Version();
int   GrLcm_Init(int nIoType,int nLcdType);
void  GrLcm_Close();

void  GrLcm_SetFontType(int nType);
int   GrLcm_GetFontType();

void  GrLcm_printf (int x, int y, char *szFmt, ...);
void  GrLcm_printf2(int x, int y, int nType, char *szFmt, ...);
void  GrLcm_printf3(int x, int y, int nLang, char *szFmt, ...);
void  GrLcm_SetLanguage(int nLang);
int   GrLcm_GetLanguage();

void  GrLcm_ClearScreen();
void  GrLcm_ClearRect(int x,int y,int xs,int ys);

void  GrLcm_DisplayBitmapFile(int x,int y,char *szFile);
void  GrLcm_DisplayBitmap(int x,int y,int xs,int ys,char *pcBuf);

void GrLcm_DrawLine(int x1, int y1, int x2, int y2);
void GrLcm_DrawDot(int x, int y);

int GrLcm_GetMaxX();
int GrLcm_GetMaxY();

#ifdef __cplusplus
}
#endif

#endif /*  _GrLcm_H_ */
